@@ -59,27 +59,19 @@
 
 static void ListNetworks(int argc, char *argv[])
 {
-	extern unsigned char *GSM_Networks[];
-	extern unsigned char *GSM_Countries[];
 	int i = 0;
-	char country[4] = "";
+	const char *country_code = NULL;
 
 	if (argc > 2) {
-		while (GSM_Countries[i * 2] != NULL) {
-			if (strncmp
-			    (GSM_Countries[i * 2 + 1], argv[2],
-			     strlen(argv[2])) == 0
-			    || strncmp(GSM_Countries[i * 2], argv[2],
-				       strlen(argv[2])) == 0) {
-				strcpy(country, GSM_Countries[i * 2]);
-				printf(_("Networks for %s:"),
-				       GSM_Countries[i * 2 + 1]);
+		for (i = 0; GSM_Countries[i].Code[0] != 0; i++) {
+			if (strcmp(GSM_Countries[i].Name, argv[2]) == 0 || strcasecmp(GSM_Countries[i].Code, argv[2]) == 0) {
+				country_code = GSM_Countries[i].Code;
+				printf(_("Networks for %s:"), GSM_Countries[i].Name);
 				printf("\n\n");
 				break;
 			}
-			i++;
 		}
-		if (!*country) {
+		if (country_code == NULL) {
 			printf(_("Unknown country name: %s."), argv[2]);
 			printf("\n");
 			Terminate(2);
@@ -87,25 +79,17 @@ static void ListNetworks(int argc, char *argv[])
 	}
 	printf("%-10s %s\n", _("Network"), _("Name"));
 	i = 0;
-	while (GSM_Networks[i * 2] != NULL) {
-		if (argc > 2) {
-			if (!strncmp
-			    (GSM_Networks[i * 2], country, strlen(country))) {
-				printf("%-10s %s\n", GSM_Networks[i * 2],
-				       GSM_Networks[i * 2 + 1]);
-			}
-		} else {
-			printf("%-10s %s\n", GSM_Networks[i * 2],
-			       GSM_Networks[i * 2 + 1]);
+	for (i = 0; GSM_Networks[i].Code[0] != 0; i++) {
+		if (country_code == NULL || strncmp(GSM_Networks[i].Code, country_code, 3) == 0) {
+			printf("%-10s %s\n", GSM_Networks[i].Code, GSM_Networks[i].Name);
 		}
-		i++;
 	}
 }
 
 static void PrintVersion(void)
 {
 	printf(_("[Gammu version %s built %s on %s using %s]"),
-	       VERSION, __TIME__, __DATE__, GetCompiler());
+	       GAMMU_VERSION, __TIME__, __DATE__, GetCompiler());
 	printf("\n\n");
 }
 
@@ -235,7 +219,7 @@ static void Features(int argc UNUSED, char *argv[]UNUSED)
 #ifdef GSM_ENABLE_BACKUP
 	printf("  - %s\n", "BACKUP");
 #endif
-#ifdef GETTEXTLIBS_FOUND
+#ifdef LIBINTL_LIB_FOUND
 	printf("  - %s\n", "GETTEXT");
 #endif
 #ifdef ICONV_FOUND
@@ -308,9 +292,9 @@ static void CheckVersion(int argc, char *argv[])
 
 			new_version[i] = 0;
 
-			if (VersionToInt(new_version) > VersionToInt(VERSION)) {
+			if (VersionToInt(new_version) > VersionToInt(GAMMU_VERSION)) {
 				printf_info(_("There is newer stable Gammu version available! (%s instead of %s)\n"),
-				       new_version, VERSION);
+				       new_version, GAMMU_VERSION);
 			}
 		}
 	}
@@ -326,9 +310,9 @@ static void CheckVersion(int argc, char *argv[])
 
 			new_version[i] = 0;
 
-			if (VersionToInt(new_version) > VersionToInt(VERSION)) {
+			if (VersionToInt(new_version) > VersionToInt(GAMMU_VERSION)) {
 				printf_info(_("There is newer testing Gammu version available! (%s instead of %s)\n"),
-				       new_version, VERSION);
+				       new_version, GAMMU_VERSION);
 			}
 		}
 	}
@@ -340,7 +324,7 @@ static void Version(int argc UNUSED, char *argv[]UNUSED)
 {
 	PrintVersion();
 
-	printf("%s\n", _("Copyright (C) 2003 - 2010 Michal Cihar <michal@cihar.com> and other authors."));
+	printf("%s\n", _("Copyright (C) 2003 - 2011 Michal Cihar <michal@cihar.com> and other authors."));
 
 	printf("\n");
 
@@ -485,9 +469,11 @@ static GSM_Parameters Parameters[] = {
 	{"getdisplaystatus",		0, 0, GetDisplayStatus,		{H_Info,0},			""},
 	{"getlocation",			0, 0, GetLocation,		{H_Info,0},			""},
 	{"monitor",			0, 1, Monitor,			{H_Info,H_Network,H_Call,0},	"[times]"},
+	{"battery",			0, 0, Battery,			{H_Info,0},			""},
 	{"setautonetworklogin",	0, 0, SetAutoNetworkLogin,	{H_Network,0},			""},
 	{"listnetworks",		0, 1, ListNetworks,		{H_Network,0},			"[country]"},
 	{"getgprspoint",		1, 2, GetGPRSPoint,		{H_Network,0},			"start [stop]"},
+	{"screenshot",			1, 1, Screenshot,		{H_Other,0},		"filenamebase"},
 	{"getfilesystemstatus",	0, 0, GetFileSystemStatus,	{H_Filesystem,0},		""},
 	{"getfilesystem",		0, 1, GetFileSystem,		{H_Filesystem,0},		"[-flatall|-flat]"},
 	{"getfilefolder",		1,40, GetFileFolder,		{H_Filesystem,0},		"fileID, fileID, ..."},
@@ -626,7 +612,7 @@ static GSM_Parameters Parameters[] = {
 	{"reset",			1, 1, Reset,			{H_Other,0},			"SOFT|HARD"},
 	{"getprofile",		1, 2, GetProfile,		{H_Settings,0},			"start [stop]"},
 	{"getsecuritystatus",		0, 0, GetSecurityStatus,	{H_Info,0},			""},
-	{"entersecuritycode",		2, 2, EnterSecurityCode,	{H_Other,0},			"PIN|PUK|PIN2|PUK2|PHONE|NETWORK code|-"},
+	{"entersecuritycode",		2, 3, EnterSecurityCode,	{H_Other,0},			"PIN|PUK|PIN2|PUK2|PHONE|NETWORK code|- [newpin|-]"},
 	{"deletewapbookmark", 	1, 2, DeleteWAPBookmark, 	{H_WAP,0},			"start [stop]"},
 	{"getwapbookmark",		1, 2, GetWAPBookmark,		{H_WAP,0},			"start [stop]"},
 	{"getwapsettings",		1, 2, GetWAPMMSSettings,	{H_WAP,0},			"start [stop]"},
@@ -654,11 +640,13 @@ static GSM_Parameters Parameters[] = {
 #if defined(WIN32) || defined(HAVE_PTHREAD)
 	{"searchphone",		0, 1, SearchPhone,		{H_Other,0},			"[-debug]"},
 #endif
+	{"install",			0, 1, Install,			{H_Other,0},			"[-minimal]"},
 #ifdef GSM_ENABLE_BACKUP
 	{"savefile",			4, 5, SaveFile,			{H_Backup,H_Calendar,0},	"CALENDAR target.vcs file location"},
 	{"savefile",			4, 5, SaveFile,			{H_Backup,H_ToDo,0},		"TODO target.vcs file location"},
 	{"savefile",			4, 5, SaveFile,			{H_Backup,H_Memory,0},		"VCARD10|VCARD21 target.vcf file SM|ME location"},
 	{"savefile",			4, 5, SaveFile,			{H_Backup,H_WAP,0},		"BOOKMARK target.url file location"},
+	{"convertbackup",		2, 2, ConvertBackup,		{H_Backup,0},			"source.file output.file"},
 	{"backup",			1, 2, DoBackup,			{H_Backup,H_Memory,H_Calendar,H_ToDo,H_Category,H_Ringtone,H_WAP,H_FM,0},			"file [-yes]"},
 	{"backupsms",			1, 2, BackupSMS,		{H_Backup,H_SMS,0},		"file [-yes|-all]"},
 	{"restore",			1, 2, Restore,			{H_Backup,H_Memory,H_Calendar,H_ToDo,H_Category,H_Ringtone,H_WAP,H_FM,0},			"file [-yes]"},
@@ -692,7 +680,6 @@ static GSM_Parameters Parameters[] = {
 	{"nokiatuneradio",		0, 0, DCT4TuneRadio,		{H_Nokia,H_FM,0},		""},
 #endif
 	{"nokiamakecamerashoot",	0, 0, DCT4MakeCameraShoot,	{H_Nokia,H_Other,0},		""},
-	{"nokiagetscreendump",	0, 0, DCT4GetScreenDump,	{H_Nokia,H_Other,0},		""},
 #endif
 #if defined(GSM_ENABLE_NOKIA_DCT3) || defined(GSM_ENABLE_NOKIA_DCT4)
 	{"nokiavibratest",		0, 0, NokiaVibraTest,		{H_Nokia,H_Tests,0},		""},
@@ -704,8 +691,8 @@ static GSM_Parameters Parameters[] = {
 	{"nokiasetphonemenus",	0, 0, NokiaSetPhoneMenus,	{H_Nokia,H_Other,0},		""},
 #endif
 #ifdef DEBUG
-	{"decodesniff",		2, 3, decodesniff,		{H_Decode,0},			"MBUS2|IRDA file [phonemodel]"},
-	{"decodebinarydump",		1, 2, decodebinarydump,		{H_Decode,0},			"file [phonemodel]"},
+	{"decodesniff",		2, 3, DecodeSniff,		{H_Decode,0},			"MBUS2|IRDA file [phonemodel]"},
+	{"decodebinarydump",		1, 2, DecodeBinaryDump,		{H_Decode,0},			"file [phonemodel]"},
 #endif
 	{"batch",			0, 1, RunBatch,			{H_Other,0},			"[file]"},
 	{"",				0, 0, NULL,			{0}, ""}
@@ -1101,7 +1088,7 @@ int main(int argc, char *argv[])
 	}
 	locales_path = INI_GetValue(cfg, "gammu", "gammuloc", FALSE);
 	GSM_InitLocales(locales_path);
-#ifdef GETTEXTLIBS_FOUND
+#ifdef LIBINTL_LIB_FOUND
 	if (locales_path != NULL) {
 		bindtextdomain("gammu", locales_path);
 	} else {
@@ -1211,9 +1198,9 @@ int main(int argc, char *argv[])
 	}
 
 	/* Check used version vs. compiled */
-	if (!strcasecmp(GetGammuVersion(), VERSION) == 0) {
+	if (!strcasecmp(GetGammuVersion(), GAMMU_VERSION) == 0) {
 		printf_err(_("Version of installed libGammu.so (%s) is different to version of Gammu (%s)\n"),
-			   GetGammuVersion(), VERSION);
+			   GetGammuVersion(), GAMMU_VERSION);
 		Terminate(98);
 	}
 
