@@ -14,7 +14,9 @@
 
 #include <gammu-error.h>
 #include <gammu-statemachine.h>
-#include <string.h>
+#include <gammu-types.h>
+
+#include <stdlib.h>		/* Needed for size_t declaration */
 
 /**
  * Key event identifiers.
@@ -129,14 +131,14 @@ typedef enum {
  *
  * \ingroup Keys
  */
-GSM_Error MakeKeySequence(char *text, GSM_KeyCode * KeyCode, size_t *Length);
+GSM_Error MakeKeySequence(char *text, GSM_KeyCode * KeyCode, size_t * Length);
 
 /**
  * Emulates key press or key release.
  *
  * \ingroup Keys
  */
-GSM_Error GSM_PressKey(GSM_StateMachine * s, GSM_KeyCode Key, bool Press);
+GSM_Error GSM_PressKey(GSM_StateMachine * s, GSM_KeyCode Key, gboolean Press);
 #endif
 
 /* Editor configuration
