@@ -336,7 +336,7 @@ GSM_Error GSM_ResetPhoneSettings(GSM_StateMachine *s, GSM_ResetSettingsType Type
 /**
  * Enters security code (PIN, PUK,...) .
  */
-GSM_Error GSM_EnterSecurityCode(GSM_StateMachine *s, GSM_SecurityCode Code)
+GSM_Error GSM_EnterSecurityCode(GSM_StateMachine *s, GSM_SecurityCode *Code)
 {
 	GSM_Error err;
 
@@ -394,7 +394,7 @@ GSM_Error GSM_GetBatteryCharge(GSM_StateMachine *s, GSM_BatteryCharge *bat)
 
 	CHECK_PHONE_CONNECTION();
 
-    memset(bat, 0, sizeof(GSM_BatteryCharge));
+	memset(bat, 0, sizeof(GSM_BatteryCharge));
 
 	err = s->Phone.Functions->GetBatteryCharge(s, bat);
 	PRINT_LOG_ERROR(err);
@@ -952,20 +952,20 @@ GSM_Error GSM_SwitchCall(GSM_StateMachine *s, int ID, gboolean next)
 /**
  * Gets call diverts.
  */
-GSM_Error GSM_GetCallDivert(GSM_StateMachine *s, GSM_MultiCallDivert *divert)
+GSM_Error GSM_GetCallDivert(GSM_StateMachine *s, GSM_CallDivert *request, GSM_MultiCallDivert *result)
 {
 	GSM_Error err;
 
 	CHECK_PHONE_CONNECTION();
 
-	err = s->Phone.Functions->GetCallDivert(s, divert);
+	err = s->Phone.Functions->GetCallDivert(s, request, result);
 	PRINT_LOG_ERROR(err);
 	return err;
 }
 /**
  * Sets call diverts.
  */
-GSM_Error GSM_SetCallDivert(GSM_StateMachine *s, GSM_MultiCallDivert *divert)
+GSM_Error GSM_SetCallDivert(GSM_StateMachine *s, GSM_CallDivert *divert)
 {
 	GSM_Error err;
 
@@ -1844,6 +1844,36 @@ GSM_Error GSM_SetGPRSAccessPoint(GSM_StateMachine *s, GSM_GPRSAccessPoint *point
 	return err;
 }
 
+/**
+ * Gets phone screenshot
+ */
+GSM_Error GSM_GetScreenshot(GSM_StateMachine *s, GSM_BinaryPicture *picture)
+{
+	GSM_Error err;
+
+	CHECK_PHONE_CONNECTION();
+
+	picture->Length = 0;
+	picture->Buffer = NULL;
+	picture->Type = 0;
+
+	err = s->Phone.Functions->GetScreenshot(s, picture);
+	PRINT_LOG_ERROR(err);
+	return err;
+}
+
+/**
+ * Gets phone screenshot
+ */
+GSM_Error GSM_Install(GSM_StateMachine *s, const char *ExtraPath, gboolean Minimal)
+{
+	GSM_Error err;
+
+	err = s->Phone.Functions->Install(s, ExtraPath, Minimal);
+	PRINT_LOG_ERROR(err);
+	return err;
+}
+
 /* How should editor hadle tabs in this file? Add editor commands here.
  * vim: noexpandtab sw=8 ts=8 sts=8:
  */
