@@ -742,6 +742,11 @@ GSM_Error GSM_UnpackSemiOctetNumber(GSM_Debug_Info *di, unsigned char *retval, c
 
 	smfprintf(di, "Number Length=%ld\n", (long)length);
 
+	if (length == 0) {
+		strcpy(Buffer, "");
+		goto out;
+	}
+
 	/* Default ouput on error */
 	strcpy(Buffer, "<NOT DECODED>");
 
@@ -766,6 +771,23 @@ GSM_Error GSM_UnpackSemiOctetNumber(GSM_Debug_Info *di, unsigned char *retval, c
 	/*without leading byte with format of number*/
 	length--;
 
+	smfprintf(di, "Number type %02x (%d %d %d %d|%d %d %d %d)\n", Number[*pos + 1],
+			Number[*pos + 1] & 0x80 ? 1 : 0,
+			Number[*pos + 1] & 0x40 ? 1 : 0,
+			Number[*pos + 1] & 0x20 ? 1 : 0,
+			Number[*pos + 1] & 0x10 ? 1 : 0,
+			Number[*pos + 1] & 0x08 ? 1 : 0,
+			Number[*pos + 1] & 0x04 ? 1 : 0,
+			Number[*pos + 1] & 0x02 ? 1 : 0,
+			Number[*pos + 1] & 0x01 ? 1 : 0
+			);
+
+	if ((Number[*pos + 1] & 0x80) == 0) {
+		smfprintf(di, "Numbering plan not supported!\n");
+		ret = ERR_UNKNOWN;
+		goto out;
+	}
+
 	switch ((Number[*pos + 1] & 0x70)) {
 	case (NUMBER_ALPHANUMERIC_NUMBERING_PLAN_UNKNOWN & 0x70):
 		if (length > 6) length++;
@@ -779,16 +801,6 @@ GSM_Error GSM_UnpackSemiOctetNumber(GSM_Debug_Info *di, unsigned char *retval, c
 		DecodeBCD(Buffer+1,Number+*pos+2, length);
 		break;
 	default:
-		smfprintf(di, "Default number %02x (%d %d %d %d|%d %d %d %d)\n",Number[*pos],
-				Number[*pos] & 0x80 ? 1 : 0,
-				Number[*pos] & 0x40 ? 1 : 0,
-				Number[*pos] & 0x20 ? 1 : 0,
-				Number[*pos] & 0x10 ? 1 : 0,
-				Number[*pos] & 0x08 ? 1 : 0,
-				Number[*pos] & 0x04 ? 1 : 0,
-				Number[*pos] & 0x02 ? 1 : 0,
-				Number[*pos] & 0x01 ? 1 : 0
-				);
 		DecodeBCD (Buffer, Number+*pos+2, length);
 		break;
 	}
