@@ -1,5 +1,6 @@
 #include "md5.h"
 #include <stdio.h>
+#include <string.h>
 
 /*
  * This code implements the MD5 message-digest algorithm.
@@ -40,7 +41,6 @@ void MD5Transform(uint32 buf[4], uint32 const in[16]);
 typedef struct MD5Context MD5_CTX;
 
 /* md5.c */
-#include <string.h>
 
 /*
  * Note: this code is harmless on little-endian machines.
@@ -56,6 +56,14 @@ static void byteReverse(unsigned char *buf, unsigned longs)
 	} while (--longs);
 }
 
+static void putu32(uint32 data, unsigned char *addr)
+{
+	addr[0] = (unsigned char)data;
+	addr[1] = (unsigned char)(data >> 8);
+	addr[2] = (unsigned char)(data >> 16);
+	addr[3] = (unsigned char)(data >> 24);
+}
+
 /*
  * Start MD5 accumulation.  Set bit count to 0 and buffer to mysterious
  * initialization constants.
@@ -155,8 +163,8 @@ void MD5Final(unsigned char digest[16], struct MD5Context *ctx)
 	byteReverse(ctx->in, 14);
 
 	/* Append length in bits and transform */
-	((uint32 *) ctx->in)[14] = ctx->bits[0];
-	((uint32 *) ctx->in)[15] = ctx->bits[1];
+	putu32(ctx->bits[0], ctx->in + (14 * 4));
+	putu32(ctx->bits[1], ctx->in + (15 * 4));
 
 	MD5Transform(ctx->buf, (uint32 *) ctx->in);
 	byteReverse((unsigned char *) ctx->buf, 4);
@@ -264,7 +272,7 @@ void MD5Transform(uint32 buf[4], uint32 const in[16])
 	buf[3] += d;
 }
 
-void CalculateMD5(unsigned char *buffer, int length, unsigned char *checksum)
+void CalculateMD5(unsigned char *buffer, int length, char *checksum)
 {
 	int 		i;
 	struct MD5Context 	m_md5;
