@@ -364,6 +364,33 @@ GSM_Error DUMMY_Initialise(GSM_StateMachine *s)
 	Priv->locale.DateFormat = GSM_Date_DDMMYYYY;
 	Priv->locale.DateSeparator = '.';
 
+	Priv->diverts.EntriesNum = 5;
+
+	Priv->diverts.Entries[0].DivertType = GSM_DIVERT_Busy;
+	Priv->diverts.Entries[0].CallType = GSM_DIVERT_VoiceCalls;
+	Priv->diverts.Entries[0].Timeout = 10;
+	EncodeUnicode(Priv->diverts.Entries[0].Number, "", 0);
+
+	Priv->diverts.Entries[1].DivertType = GSM_DIVERT_NoAnswer;
+	Priv->diverts.Entries[1].CallType = GSM_DIVERT_FaxCalls;
+	Priv->diverts.Entries[1].Timeout = 20;
+	EncodeUnicode(Priv->diverts.Entries[1].Number, "123", 3);
+
+	Priv->diverts.Entries[2].DivertType = GSM_DIVERT_OutOfReach;
+	Priv->diverts.Entries[2].CallType = GSM_DIVERT_DataCalls;
+	Priv->diverts.Entries[2].Timeout = 30;
+	EncodeUnicode(Priv->diverts.Entries[2].Number, "123", 3);
+
+	Priv->diverts.Entries[3].DivertType = GSM_DIVERT_NoAnswer;
+	Priv->diverts.Entries[3].CallType = GSM_DIVERT_VoiceCalls;
+	Priv->diverts.Entries[3].Timeout = 40;
+	EncodeUnicode(Priv->diverts.Entries[3].Number, "123", 3);
+
+	Priv->diverts.Entries[4].DivertType = GSM_DIVERT_AllTypes;
+	Priv->diverts.Entries[4].CallType = GSM_DIVERT_AllCalls;
+	Priv->diverts.Entries[4].Timeout = 0;
+	EncodeUnicode(Priv->diverts.Entries[4].Number, "", 0);
+
 	return ERR_NONE;
 }
 
@@ -693,7 +720,11 @@ GSM_Error DUMMY_DialService(GSM_StateMachine *s, char *number)
 
 GSM_Error DUMMY_AnswerCall(GSM_StateMachine *s, int ID, gboolean all)
 {
-	return ERR_NOTIMPLEMENTED;
+	GSM_Phone_DUMMYData	*Priv = &s->Phone.Data.Priv.DUMMY;
+
+	fprintf(Priv->log_file, "Answering call %d (%d)\n", ID, all);
+
+	return ERR_NONE;
 }
 
 GSM_Error DUMMY_GetNetworkInfo(GSM_StateMachine *s, GSM_NetworkInfo *netinfo)
@@ -751,7 +782,11 @@ GSM_Error DUMMY_Reset(GSM_StateMachine *s, gboolean hard)
 
 GSM_Error DUMMY_CancelCall(GSM_StateMachine *s, int ID, gboolean all)
 {
-	return ERR_NOTIMPLEMENTED;
+	GSM_Phone_DUMMYData	*Priv = &s->Phone.Data.Priv.DUMMY;
+
+	fprintf(Priv->log_file, "Canceling call %d (%d)\n", ID, all);
+
+	return ERR_NONE;
 }
 
 GSM_Error DUMMY_SendSavedSMS(GSM_StateMachine *s, int Folder, int Location)
@@ -850,34 +885,45 @@ GSM_Error DUMMY_GetSIMIMSI(GSM_StateMachine *s, char *IMSI)
 	return ERR_NONE;
 }
 
-GSM_Error DUMMY_GetCallDivert(GSM_StateMachine *s, GSM_MultiCallDivert *divert)
+GSM_Error DUMMY_GetCallDivert(GSM_StateMachine *s, GSM_CallDivert *request, GSM_MultiCallDivert *response)
 {
-	divert->Response.EntriesNum = 5;
+	int i;
+	GSM_Phone_DUMMYData	*Priv = &s->Phone.Data.Priv.DUMMY;
 
-	divert->Response.Entries[0].DivertType = GSM_DIVERT_VoiceCalls;
-	divert->Response.Entries[0].CallType = GSM_DIVERT_Busy;
-	divert->Response.Entries[0].Timeout = 10;
-	EncodeUnicode(divert->Response.Entries[0].Number, "", 0);
+	response->EntriesNum = 0;
 
-	divert->Response.Entries[1].DivertType = GSM_DIVERT_FaxCalls;
-	divert->Response.Entries[1].CallType = GSM_DIVERT_NoAnswer;
-	divert->Response.Entries[1].Timeout = 20;
-	EncodeUnicode(divert->Response.Entries[1].Number, "123", 3);
+	for (i = 0; i < Priv->diverts.EntriesNum; i++) {
+		if (request->DivertType == Priv->diverts.Entries[i].DivertType && request->CallType == Priv->diverts.Entries[i].CallType) {
+			response->Entries[response->EntriesNum] = Priv->diverts.Entries[i];
+			response->EntriesNum++;
+		}
+	}
 
-	divert->Response.Entries[2].DivertType = GSM_DIVERT_DataCalls;
-	divert->Response.Entries[2].CallType = GSM_DIVERT_OutOfReach;
-	divert->Response.Entries[2].Timeout = 30;
-	EncodeUnicode(divert->Response.Entries[2].Number, "123", 3);
+	return ERR_NONE;
+}
 
-	divert->Response.Entries[3].DivertType = GSM_DIVERT_VoiceCalls;
-	divert->Response.Entries[3].CallType = GSM_DIVERT_NoAnswer;
-	divert->Response.Entries[3].Timeout = 40;
-	EncodeUnicode(divert->Response.Entries[3].Number, "123", 3);
+GSM_Error DUMMY_SetCallDivert(GSM_StateMachine *s, GSM_CallDivert *request)
+{
+	int i;
+	GSM_Phone_DUMMYData	*Priv = &s->Phone.Data.Priv.DUMMY;
 
-	divert->Response.Entries[4].DivertType = GSM_DIVERT_AllCalls;
-	divert->Response.Entries[4].CallType = GSM_DIVERT_AllTypes;
-	divert->Response.Entries[4].Timeout = 0;
-	EncodeUnicode(divert->Response.Entries[4].Number, "", 0);
+	for (i = 0; i < Priv->diverts.EntriesNum; i++) {
+		if ((request->DivertType == Priv->diverts.Entries[i].DivertType) &&
+		    (request->CallType == Priv->diverts.Entries[i].CallType)) {
+			break;
+		}
+	}
+	Priv->diverts.Entries[i] = *request;
+	Priv->diverts.EntriesNum = i + 1;
+
+	return ERR_NONE;
+}
+
+GSM_Error DUMMY_CancelAllDiverts(GSM_StateMachine *s)
+{
+	GSM_Phone_DUMMYData	*Priv = &s->Phone.Data.Priv.DUMMY;
+
+	Priv->diverts.EntriesNum = 0;
 
 	return ERR_NONE;
 }
@@ -1160,7 +1206,7 @@ GSM_Error DUMMY_GetFolderListing(GSM_StateMachine *s, GSM_File *File, gboolean s
 			closedir(Priv->dir[DUMMY_MAX_FS_DEPTH]);
 		}
 		path = DUMMY_GetFSFilePath(s, File->ID_FullName);
-		printf("listing %s\n", path);
+		smprintf(s, "listing %s\n", path);
 		strcpy(Priv->dirnames[DUMMY_MAX_FS_DEPTH], path);
 		Priv->dir[DUMMY_MAX_FS_DEPTH] = opendir(path);
 		free(path);
@@ -1957,8 +2003,8 @@ GSM_Phone_Functions DUMMYPhone = {
  	NOTSUPPORTED,			/* 	TransferCall		*/
  	NOTSUPPORTED,			/* 	SwitchCall		*/
 	DUMMY_GetCallDivert,
- 	NOTSUPPORTED,			/* 	SetCallDivert		*/
- 	NOTSUPPORTED,			/* 	CancelAllDiverts	*/
+ 	DUMMY_SetCallDivert,
+ 	DUMMY_CancelAllDiverts,
 	DUMMY_SetIncomingCall,
 	DUMMY_SetIncomingUSSD,
 	DUMMY_SendDTMF,
