@@ -12,7 +12,7 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * Copyright (c) 2011 Michal Cihar <michal@cihar.com>
+ * Copyright (c) 2011 - 2012 Michal Cihar <michal@cihar.com>
  */
 
 
@@ -29,7 +29,7 @@
 
 #if defined(GSM_ENABLE_S60)
 
-GSM_Error S60_Install(GSM_StateMachine *s, const char *ExtraPath)
+GSM_Error S60_Install(GSM_StateMachine *s, const char *ExtraPath, gboolean Minimal)
 {
 	GSM_StateMachine *gsm;
 	GSM_Debug_Info *debug_info;
@@ -45,33 +45,41 @@ GSM_Error S60_Install(GSM_StateMachine *s, const char *ExtraPath)
 	AppletFile.Buffer 	= NULL;
 	AppletFile.Used 	= 0;
 
-	error = PHONE_FindDataFile(s, &AppletFile, ExtraPath, "series60-remote.sis");
+	error = PHONE_FindDataFile(s, &AppletFile, ExtraPath, "gammu-s60-remote.sis");
 	if (error != ERR_NONE) {
 		smprintf(s, "Failed to find applet, trying another filename!\n");
-		error = PHONE_FindDataFile(s, &AppletFile, ExtraPath, "series60-remote-sign.sis");
+		error = PHONE_FindDataFile(s, &AppletFile, ExtraPath, "gammu-s60-remote-sign.sis");
 		if (error != ERR_NONE) {
 			smprintf(s, "Failed to load applet data!\n");
 			return ERR_INSTALL_NOT_FOUND;
 		}
 	}
 
-	error = PHONE_FindDataFile(s, &PythonFile, ExtraPath, "Python_2.0.0.sis");
-	if (error == ERR_NONE) {
-		install_python = TRUE;
-	} else {
-		smprintf(s, "Could not find Python for S60 to install, skipping!\n");
+	if (Minimal) {
+
 		install_python = FALSE;
 		install_pips = FALSE;
-	}
 
-	if (install_python) {
-		error = PHONE_FindDataFile(s, &PIPSFile, ExtraPath, "pips.sis");
+	} else {
+
+		error = PHONE_FindDataFile(s, &PythonFile, ExtraPath, "Python_2.0.0.sis");
 		if (error == ERR_NONE) {
-			install_pips = TRUE;
+			install_python = TRUE;
 		} else {
-			smprintf(s, "Could not find PIPS to install, skipping!\n");
+			smprintf(s, "Could not find Python for S60 to install, skipping!\n");
+			install_python = FALSE;
 			install_pips = FALSE;
 		}
+
+		if (install_python) {
+			error = PHONE_FindDataFile(s, &PIPSFile, ExtraPath, "pips.sis");
+			if (error == ERR_NONE) {
+				install_pips = TRUE;
+			} else {
+				smprintf(s, "Could not find PIPS to install, skipping!\n");
+				install_pips = FALSE;
+			}
+		}
 	}
 
 	gsm = GSM_AllocStateMachine();
@@ -174,7 +182,7 @@ GSM_Error S60_Initialise(GSM_StateMachine *s)
 		return error;
 	}
 
-	if (Priv->MajorVersion != 1 || Priv->MinorVersion != 5) {
+	if (Priv->MajorVersion != 1 || Priv->MinorVersion != 6) {
 		smprintf(s, "Unsupported protocol version\n");
 		return ERR_NOTSUPPORTED;
 	}
@@ -279,7 +287,7 @@ static GSM_Error S60_Reply_SendSMS(GSM_Protocol_Message *msg, GSM_StateMachine *
 			if (s->User.SendSMSStatus != NULL) {
 				s->User.SendSMSStatus(s, 1, -1, s->User.SendSMSStatusUserData);
 			}
-			return ERR_UNKNOWN;
+			return ERR_BUSY;
 		case NUM_MESSAGE_SEND_REPLY_STATUS:
 			return ERR_NONE;
 		case NUM_MESSAGE_SEND_REPLY_OK:
@@ -308,7 +316,7 @@ static GSM_Error S60_Reply_Connect(GSM_Protocol_Message *msg, GSM_StateMachine *
 		return ERR_UNKNOWN;
 	}
 	Priv->MinorVersion = atoi(pos + 1);
-	smprintf(s, "Connected to series60-remote version %d.%d\n", Priv->MajorVersion, Priv->MinorVersion);
+	smprintf(s, "Connected to Gammu S60 Remote version %d.%d\n", Priv->MajorVersion, Priv->MinorVersion);
 
 	return ERR_NONE;
 }
@@ -765,6 +773,8 @@ static GSM_Error S60_Reply_GetMemory(GSM_Protocol_Message *msg, GSM_StateMachine
 	} else if(strcmp(type, "email_address") == 0) {
 		text = TRUE;
 		Entry->Entries[Entry->EntriesNum].EntryType = PBK_Text_Email;
+	} else if(strcmp(type, "po_box") == 0) {
+		text = TRUE;
 	} else if(strcmp(type, "extended_address") == 0) {
 		text = TRUE;
 	} else if(strcmp(type, "fax_number") == 0) {
@@ -841,10 +851,18 @@ static GSM_Error S60_Reply_GetMemory(GSM_Protocol_Message *msg, GSM_StateMachine
 	}
 
 	if (text) {
+		if (strlen(value) == 0) {
+			/* Ignore empty responses */
+			return ERR_NEEDANOTHERANSWER;
+		}
 		DecodeUTF8(Entry->Entries[Entry->EntriesNum].Text, value, strlen(value));
 	}
 
 	Entry->EntriesNum++;
+	if (Entry->EntriesNum >= GSM_PHONEBOOK_ENTRIES) {
+		smprintf(s, "ERROR: reached limit of phonebook entries\n");
+		return ERR_MOREMEMORY;
+	}
 
 	return ERR_NEEDANOTHERANSWER;
 }
@@ -1900,6 +1918,7 @@ GSM_Error S60_GetNextSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sms, gboolean
 GSM_Error S60_SendSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 {
 	char buffer[((GSM_MAX_SMS_LENGTH + 1) * 2) + ((GSM_MAX_SMS_NAME_LENGTH + 1) * 2) + ((GSM_MAX_NUMBER_LENGTH + 1) * 2)];
+	char textbuffer[((GSM_MAX_SMS_LENGTH + 1) * 2)];
 
 	if (sms->UDH.Type != UDH_NoUDH) {
 		return ERR_NOTSUPPORTED;
@@ -1923,7 +1942,8 @@ GSM_Error S60_SendSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 			break;
 	}
 	strcat(buffer, NUM_SEPERATOR_STR);
-	EncodeUTF8(buffer + strlen(buffer), sms->Text);
+	EncodeUTF8(textbuffer, sms->Text);
+	EncodeSpecialChars(buffer + strlen(buffer), textbuffer);
 	strcat(buffer, NUM_SEPERATOR_STR);
 
 	return GSM_WaitFor(s, buffer, strlen(buffer), NUM_MESSAGE_SEND_REQUEST, S60_TIMEOUT, ID_None);
